@@ -335,15 +335,14 @@ class SpectrumModel:
         cov = X.T @ cho_solve((L, flag), X)
 
         # Trivial covariance
-        np.fill_diagonal(cov, cov.diagonal() + self.data.sigma ** 2)
+        np.fill_diagonal(cov, cov.diagonal() + self.data.sigma**2)
 
         # Global covariance
         if "global_cov" in self.params:
             if "global_cov" not in self.frozen or self._glob_cov is None:
                 ag = np.exp(self.params["global_cov:log_amp"])
                 lg = np.exp(self.params["global_cov:log_ls"])
-                T = self.params["T"]
-                self._glob_cov = global_covariance_matrix(self.data.wave, T, ag, lg)
+                self._glob_cov = global_covariance_matrix(self.data.wave, ag, lg)
 
         if self._glob_cov is not None:
             cov += self._glob_cov
